Enum style::properties::longhands::display::SpecifiedValue
[−]
[src]
pub enum SpecifiedValue {
Inline,
Block,
InlineBlock,
Table,
InlineTable,
TableRowGroup,
TableHeaderGroup,
TableFooterGroup,
TableRow,
TableColumnGroup,
TableColumn,
TableCell,
TableCaption,
ListItem,
None,
Flex,
InlineFlex,
}Variants
InlineBlockInlineBlockTableInlineTableTableRowGroupTableHeaderGroupTableRowTableColumnGroupTableColumnTableCellTableCaptionListItemNoneFlexInlineFlex
Methods
impl Display[src]
pub fn is_item_container(&self) -> bool[src]
Returns whether this "display" value is the display of a flex or grid container.
This is used to implement various style fixups.
pub fn is_line_participant(&self) -> bool[src]
Returns whether an element with this display type is a line participant, which means it may lay its children on the same line as itself.
pub fn should_ignore_parsed_value(
_old_display: Self,
_new_display: Self
) -> bool[src]
_old_display: Self,
_new_display: Self
) -> bool
Whether new_display should be ignored, given a previous
old_display value.
This is used to ignore display: -moz-box declarations after an
equivalent display: -webkit-box declaration, since the former
has a vastly different meaning. See bug 1107378 and bug 1407701.
FIXME(emilio): This is a pretty decent hack, we should try to remove it.
pub fn equivalent_block_display(&self, _is_root_element: bool) -> Self[src]
Convert this display into an equivalent block display.
Also used for style adjustments.